#[non_exhaustive]pub enum VrdError {
GeneralError(&'static str),
}Expand description
Crate-level error type for the vrd library.
This error type is used to represent general failures within the library.
It is kept allocation-free by using static error messages, ensuring it
works correctly in pure no_std environments without requiring an
allocator.
Examples
use vrd::VrdError;
let err = VrdError::GeneralError("something went wrong");
println!("{}", err);Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GeneralError(&'static str)
A general error with a static message.
This variant is used for unexpected conditions where a more specific error type isn’t applicable.